@@ -14,6 +14,7 @@
 
 {-# LANGUAGE MultiParamTypeClasses, FunctionalDependencies, FlexibleContexts,
              UndecidableInstances #-}
+{-# OPTIONS_HADDOCK not-home #-}
 
 module Text.Parsec.Prim
     ( unknownError
@@ -67,6 +68,13 @@ module Text.Parsec.Prim
     , updateState
     ) where
 
+
+import qualified Data.ByteString.Lazy.Char8 as CL
+import qualified Data.ByteString.Char8 as C
+
+import qualified Data.Text as Text
+import qualified Data.Text.Lazy as TextL
+
 import qualified Control.Applicative as Applicative ( Applicative(..), Alternative(..) )
 import Control.Monad()
 import Control.Monad.Trans
@@ -272,7 +280,7 @@ instance MonadPlus (ParsecT s u m) where
 
 -- | @parserZero@ always fails without consuming any input. @parserZero@ is defined
 -- equal to the 'mzero' member of the 'MonadPlus' class and to the 'Control.Applicative.empty' member 
--- of the 'Control.Applicative.Applicative' class.
+-- of the 'Control.Applicative.Alternative' class.
 
 parserZero :: ParsecT s u m a
 parserZero
@@ -299,7 +307,7 @@ instance MonadTrans (ParsecT s u) where
 infix  0 <?>
 infixr 1 <|>
 
--- | The parser @p <?> msg@ behaves as parser @p@, but whenever the
+-- | The parser @p \<?> msg@ behaves as parser @p@, but whenever the
 -- parser @p@ fails /without consuming any input/, it replaces expect
 -- error messages with the expect error message @msg@.
 --
@@ -329,6 +337,7 @@ p <?> msg = label p msg
 (<|>) :: (ParsecT s u m a) -> (ParsecT s u m a) -> (ParsecT s u m a)
 p1 <|> p2 = mplus p1 p2
 
+-- | A synonym for @\<?>@, but as a function instead of an operator.
 label :: ParsecT s u m a -> String -> ParsecT s u m a
 label p msg
   = labels p [msg]
@@ -363,6 +372,27 @@ labels p msgs =
 class (Monad m) => Stream s m t | s -> t where
     uncons :: s -> m (Maybe (t,s))
 
+instance (Monad m) => Stream [tok] m tok where
+    uncons []     = return $ Nothing
+    uncons (t:ts) = return $ Just (t,ts)
+    {-# INLINE uncons #-}
+
+
+instance (Monad m) => Stream CL.ByteString m Char where
+    uncons = return . CL.uncons
+
+instance (Monad m) => Stream C.ByteString m Char where
+    uncons = return . C.uncons
+
+instance (Monad m) => Stream Text.Text m Char where
+    uncons = return . Text.uncons
+    {-# INLINE uncons #-}
+
+instance (Monad m) => Stream TextL.Text m Char where
+    uncons = return . TextL.uncons
+    {-# INLINE uncons #-}
+
+
 tokens :: (Stream s m t, Eq t)
        => ([t] -> String)      -- Pretty print a list of tokens
        -> (SourcePos -> [t] -> SourcePos)
@@ -442,14 +472,10 @@ try p =
 -- if this is undesirable.
 
 lookAhead :: (Stream s m t) => ParsecT s u m a -> ParsecT s u m a
-lookAhead p         = do{ state <- getParserState
-                        ; x <- p'
-                        ; setParserState state
-                        ; return x
-                        }
-    where
-    p' = ParsecT $ \s cok cerr eok eerr ->
-         unParser p s eok cerr eok eerr
+lookAhead p =
+    ParsecT $ \s _ cerr eok eerr -> do
+        let eok' a _ _ = eok a s (newErrorUnknown (statePos s))
+        unParser p s eok' cerr eok' eerr
 
 -- | The parser @token showTok posFromTok testTok@ accepts a token @t@
 -- with result @x@ when the function @testTok t@ returns @'Just' x@. The
