@@ -38,7 +38,7 @@ import Text.Parsec.Combinator
 type LanguageDef st = GenLanguageDef String st Identity
 
 -- | The @GenLanguageDef@ type is a record that contains all parameterizable
--- features of the 'Text.Parsec.Token' module. The module 'Text.Parsec.Language'
+-- features of the "Text.Parsec.Token" module. The module "Text.Parsec.Language"
 -- contains some default definitions.
 
 data GenLanguageDef s u m
@@ -64,12 +64,12 @@ data GenLanguageDef s u m
     nestedComments :: Bool,
 
     -- | This parser should accept any start characters of identifiers. For
-    -- example @letter \<|> char \"_\"@. 
+    -- example @letter \<|> char \'_\'@. 
 
     identStart     :: ParsecT s u m Char,
 
     -- | This parser should accept any legal tail characters of identifiers.
-    -- For example @alphaNum \<|> char \"_\"@. 
+    -- For example @alphaNum \<|> char \'_\'@. 
 
     identLetter    :: ParsecT s u m Char,
 
@@ -448,7 +448,7 @@ makeTokenParser languageDef
 
     charControl     = do{ char '^'
                         ; code <- upper
-                        ; return (toEnum (fromEnum code - fromEnum 'A'))
+                        ; return (toEnum (fromEnum code - fromEnum 'A' + 1))
                         }
 
     charNum         = do{ code <- decimal
